1.15.4 — Rucio 1.2 documentation

# 1.15.4

## General

### Enhancements

- Core & Internals: rucio-judge-cleaner traceback against postgres #722
- Core & Internals: Keyword parameters should always be used for instansiating datetime.timedelta #807
- Documentation: Add external link for ActiveMQ for people joining the project #1001
- Documentation: Typographical Review of Documentation Files #985
- Release management: Add python3 in the rucio dev docker image #973

## Clients

### Enhancements

- Clients: section policy/support/rucio_support missing in rucio.cfg template and tests #976

### Bugs

- Clients: Error with python3: the JSON object must be str, not ‘bytes’ #964
- Clients: Client AttributeError when the server returns nothing #965
- Release management: setup_clients.py classifiers needs to be a list, not tuples #949